# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Annotations

Package implementing the function type annotations checker.

### Modules

AnnotationsChecker | Module implementing a checker for function type annotations.
AnnotationsCheckerDefaults | Module implementing complex defaults for the annotations checker.
AnnotationsDeprecationsVisitor | Module implementing a node visitor for checking the use of deprecated 'typing' symbols.
AnnotationsEnums | Module implementing some enums for function type annotations.
AnnotationsFunctionVisitor | Module implementing a node visitor for function type annotations.
AnnotationsFutureVisitor | Module implementing a node visitor for function type annotations.
AnnotationsUnionVisitor | Module implementing a node visitor for checking the import of typing.Union.
translations | Module implementing message translations for the code style plugin messages (code annotations part).